==> dclib-0.3.14a.tar.bz2: dclib-0.3.14a/dclib/csearchindex.h <==
/***************************************************************************
                           csearchindex.h  -  description
                             -------------------
    begin                : Mon May 14 2003
    copyright            : (C) 2003-2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CSEARCHINDEX_H
#define CSEARCHINDEX_H

/**
  *@author Mathias Kster
  */

#include <dclib/dcos.h>

#pragma pack(1)

typedef struct filebaseobject {
	/** */
	unsigned int m_eFileType;
	/** */
	ulonglong m_nSize;
	/** */
	unsigned long m_nPathIndex;
	/** */
	unsigned long m_nFileIndex;
	/** */
	unsigned long m_nHashIndex;
	/** */
	time_t m_tModTime;
} filebaseobject;

typedef struct searchindexobject {
	/** */
	unsigned long m_nIndex;
	/** */
	unsigned long m_nFileIndex;
} searchindexobject;

typedef struct fileindexobject {
	/** */
	ulonglong m_nFileBaseIndex;
	/** */
	unsigned long m_nNext;
} fileindexobject;

typedef struct hashbaseobject {
	/** */
	ulonglong m_nSize;
	/** */
	unsigned long m_nPathIndex;
	/** */
	unsigned long m_nFileIndex;
	/** */
	unsigned long m_nHashIndex;
	/** */
	unsigned long m_nHashLeavesIndex;
	/** */
	time_t m_tModTime;
} hashbaseobject;

typedef struct long_s {
	/** */
	unsigned long n;
} long_s;

#pragma pack()

class CByteArray;

class DLL_EXPORT CSearchIndex : public CObject {

public:
	/** */
	CSearchIndex();
	/** */
	virtual ~CSearchIndex();

	/** */
	bool LoadIndex();
	/** */
	void SaveIndex();
	/** */
	void Reset();
	/** */
	void ResetIndex();
	/** */
	void ResetHashIndex();
	/** */
	void InitIndex();

	/** */
	CStringList * Search( CString s );
	/** */
	CStringList * SearchHash( unsigned char * hash );

	/** */
	bool GetFileBaseObject( ulonglong index, struct filebaseobject * fbo );
	/** */
	bool GetFileBaseObject( CString id, struct filebaseobject * fbo, CString & filename );

	/** */
	CString GetFileName( ulonglong i );
	/** */
	void AddIndex( CString & s, ulonglong filebaseindex );
	/** */
	unsigned long AddIndex( CFileInfo *fileinfo, CString path, eFileTypes filetype );
	/** */
	void UpdateIndex( ulonglong index, struct filebaseobject * fbo );
	/** */
	unsigned long IndexCount();
	
	/** */
	bool FindHash( unsigned char * hash, ulonglong * hi );
	/** */
	CString GetHash( ulonglong hbi );
	/** */
	bool HashBaseIndexFromHashIndex( ulonglong hi, ulonglong * hbi );
	/** */
	bool BaseIndexFromHashBaseIndex( ulonglong hbi, ulonglong * bi );
	/** */
	void AddHashIndex( ulonglong filebaseindex, unsigned char * hash, unsigned char * leaves, unsigned int lsize );
	/** */
	bool FindHashBaseIndex( struct filebaseobject * fbo, ulonglong * hbi );
	/** */
	bool Compare( struct filebaseobject * fbo, struct hashbaseobject * hbo );
	/** Get the TTH leaves for the given TTH */
	CByteArray * GetHashLeaves( CString tth );
	/** Opens the hashleaves file */
	bool OpenHashLeaves();
	/** Closes the hashleaves file */
	bool CloseHashLeaves();
	/** Rebuild the byte arrays, removing no longer needed data */
	void RebuildLists();
	/** Print out some stats */
	void PrintDatabaseStats();

private:
	/** */
	struct searchindexobject * FindIndex( CString & s );
	/** */
	struct searchindexobject * SearchIndex( CString & s );

	/** */
	CByteArray * m_pFileBaseArray;
	/** */
	CByteArray * m_pPathBaseArray;
	/** */
	CByteArray * m_pBaseArray;
	/** */
	CByteArray * m_pSearchIndex;
	/** */
	CByteArray * m_pSearchFileIndex;
	/** */
	CByteArray * m_pSearchBase;
	/** */
	CByteArray * m_pSearchArray[0x100];
	/** */
	struct long_s * m_nSearchFileIndex;
	
	/** */
	CByteArray * m_pHashBaseArray;
	/** */
	CByteArray * m_pHashFileBaseArray;
	/** */
	CByteArray * m_pHashPathBaseArray;
	/** */
	CByteArray * m_pHashIndex;
	/** */
	CByteArray * m_pHashLeaves;
};

#endif

==> dclib-0.3.17.tar.bz2: dclib-0.3.17/dclib/csearchindex.h <==
/***************************************************************************
                           csearchindex.h  -  description
                             -------------------
    begin                : Mon May 14 2003
    copyright            : (C) 2003-2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CSEARCHINDEX_H
#define CSEARCHINDEX_H

/**
  *@author Mathias Kster
  */

#include <dclib/dcos.h>

#pragma pack(1)

typedef struct filebaseobject {
	/** */
	unsigned int m_eFileType;
	/** */
	ulonglong m_nSize;
	/** */
	unsigned long m_nPathIndex;
	/** */
	unsigned long m_nFileIndex;
	/** */
	unsigned long m_nHashIndex;
	/** */
	time_t m_tModTime;
} filebaseobject;

typedef struct searchindexobject {
	/** */
	unsigned long m_nIndex;
	/** */
	unsigned long m_nFileIndex;
} searchindexobject;

typedef struct fileindexobject {
	/** */
	ulonglong m_nFileBaseIndex;
	/** */
	unsigned long m_nNext;
} fileindexobject;

typedef struct hashbaseobject {
	/** */
	ulonglong m_nSize;
	/** */
	unsigned long m_nPathIndex;
	/** */
	unsigned long m_nFileIndex;
	/** */
	unsigned long m_nHashIndex;
	/** */
	unsigned long m_nHashLeavesIndex;
	/** */
	time_t m_tModTime;
} hashbaseobject;

typedef struct long_s {
	/** */
	unsigned long n;
} long_s;

#pragma pack()

class CByteArray;

class DLL_EXPORT CSearchIndex : public CObject {

public:
	/** */
	CSearchIndex();
	/** */
	virtual ~CSearchIndex();

	/** */
	bool LoadIndex();
	/** */
	void SaveIndex();
	/** */
	void PrepareUpdate();
	/** */
	void FinishUpdate();
	/** */
	void ResetHashIndex();
	/** */
	void InitIndex();

	/** */
	CStringList * Search( CString s );
	/** */
	CStringList * SearchHash( unsigned char * hash );

	/** */
	bool GetFileBaseObject( ulonglong index, struct filebaseobject * fbo );
	/** */
	bool GetFileBaseObjectDuringUpdate( ulonglong index, struct filebaseobject * fbo );
	/** */
	bool GetFileBaseObject( CString id, struct filebaseobject * fbo, CString & filename );
	/** */
	bool GetFileBaseObjectDuringUpdate( CString id, struct filebaseobject * fbo, CString & filename );
	
	/** */
	CString GetFileName( ulonglong i );
	/** */
	CString GetFileNameDuringUpdate( ulonglong i );
	/** */
	void AddIndex( CString & s, ulonglong filebaseindex );
	/** */
	unsigned long AddIndex( CFileInfo *fileinfo, CString path, eFileTypes filetype );
	/** */
	void UpdateIndex( ulonglong index, struct filebaseobject * fbo );
	/** */
	unsigned long IndexCount();
	/** */
	unsigned long IndexCountDuringUpdate();
	
	/** */
	bool FindHash( unsigned char * hash, ulonglong * hi );
	/** */
	bool FindHashDuringUpdate( unsigned char * hash, ulonglong * hi );
	/** */
	CString GetHash( ulonglong hbi );
	/** */
	bool HashBaseIndexFromHashIndex( ulonglong hi, ulonglong * hbi );
	/** */
	bool HashBaseIndexFromHashIndexDuringUpdate( ulonglong hi, ulonglong * hbi );
	/** */
	bool BaseIndexFromHashBaseIndex( ulonglong hbi, ulonglong * bi );
	/** */
	void AddHashIndex( ulonglong filebaseindex, unsigned char * hash, unsigned char * leaves, unsigned int lsize );
	/** */
	bool FindHashBaseIndex( struct filebaseobject * fbo, ulonglong * hbi );
	/** */
	bool FindHashBaseIndexDuringUpdate( struct filebaseobject * fbo, ulonglong * hbi );
	/** */
	bool Compare( struct filebaseobject * fbo, struct hashbaseobject * hbo );
	/** */
	bool CompareDuringUpdate( struct filebaseobject * fbo, struct hashbaseobject * hbo );
	/** Get the TTH leaves for the given TTH */
	CByteArray * GetHashLeaves( CString tth );
	/** Appends newly created hash leaf data to hashleaves.bin */
	bool SaveNewHashLeaves();
	/** Rebuild the byte arrays, removing no longer needed data */
	void RebuildLists();
	/** Print out some stats */
	void PrintDatabaseStats();
	/** Returns what LoadIndex() in constructor returned. */
	bool LoadedOK() const { return m_bLoadedOK; } ;

private:
	/** */
	bool m_bLoadedOK;
	/** */
	struct searchindexobject * FindIndex( CString & s );
	/** */
	struct searchindexobject * SearchIndex( CString & s );

	/** read only */
	CByteArray * m_pFileBaseArray;
	/** read only */
	CByteArray * m_pPathBaseArray;
	/** read only */
	CByteArray * m_pBaseArray;
	/** read only */
	CByteArray * m_pSearchIndex;
	/** read only */
	CByteArray * m_pSearchFileIndex;
	/** read only */
	CByteArray * m_pSearchBase;
	/** only appears to be used during search index creation */
	CByteArray * m_pSearchArray[0x100];
	/** */
	struct long_s * m_nSearchFileIndex;
	
	/** read only */
	CByteArray * m_pHashBaseArray;
	/** read only */
	CByteArray * m_pHashFileBaseArray;
	/** read only */
	CByteArray * m_pHashPathBaseArray;
	/** read only */
	CByteArray * m_pHashIndex;
	/**
	 * Newly created hash leaf data to append to hashleaves.bin
	 * There is no need to load the whole file into memory.
	 */
	CByteArray * m_pNewHashLeaves;
	/** The size of hashleaves.bin */
	ulonglong hashleavessize;
	
	/** writeable */
	CByteArray * m_pUpdatingFileBaseArray;
	/** writeable */
	CByteArray * m_pUpdatingPathBaseArray;
	/** writeable */
	CByteArray * m_pUpdatingBaseArray;

	/** writeable */
	CByteArray * m_pUpdatingSearchIndex;
	/** writeable */
	CByteArray * m_pUpdatingSearchFileIndex;
	/** writeable */
	CByteArray * m_pUpdatingSearchBase;
	/** */
	struct long_s * m_nUpdatingSearchFileIndex;
	
	/** writeable */
	CByteArray * m_pUpdatingHashBaseArray;
	/** writeable */
	CByteArray * m_pUpdatingHashFileBaseArray;
	/** writeable */
	CByteArray * m_pUpdatingHashPathBaseArray;
	/** writeable */
	CByteArray * m_pUpdatingHashIndex;
};

#endif
